(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     16772,        522]
NotebookOptionsPosition[     14980,        461]
NotebookOutlinePosition[     15403,        477]
CellTagsIndexPosition[     15360,        474]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Methoden der Bioinformatik",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox[" \n\n",
  FontSize->12],
 "Eine Einf\[UDoubleDot]hrung zur Anwendung in Biologie und Medizin\n\n2. \
Auflage",
 StyleBox["\n",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontSize->12],
 "Marc-Thorsten H\[UDoubleDot]tt",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "und",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "Manuel Dehnert\n",
 StyleBox["\n",
  FontSize->12],
 "Springer Spektrum",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "2006",
 StyleBox[", ",
  FontSize->12,
  FontWeight->"Bold"],
 "2016, ISBN 978-3-662-46149-5"
}], "Subsubtitle",
 CellChangeTimes->{{3.669868691792925*^9, 3.669868786167323*^9}, {
  3.6698688284727426`*^9, 3.669868879042635*^9}, {3.6698691142260866`*^9, 
  3.6698691148331213`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: DAR(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")-Prozess"
}], "Subtitle",
 CellChangeTimes->{
  3.670321495640956*^9, 3.670402706588908*^9, {3.670427551024929*^9, 
   3.670427553031043*^9}},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "Der Parameter \[Rho] des DAR(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")-Prozesses aus Gl. (4.16) gibt die Wahrscheinlichkeit an, dass das Symbol ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["X", "n"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " aus den vorausgegangenen Symbolen der Sequenz gew\[ADoubleDot]hlt wird. \
Indem wir diesem Parameter den Wert 0.6 zuweisen, ist die Wahrscheinlichkeit \
f\[UDoubleDot]r einen R\[UDoubleDot]ckgriff innerhalb der Sequenz also auf 60 \
% gesetzt."
}], "Text",
 CellChangeTimes->{{3.6761562353721595`*^9, 3.6761562638338127`*^9}, 
   3.6761563053516884`*^9, {3.6761563364423447`*^9, 3.676156379647024*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]", "=", "0.6"}], ";"}]], "Input"],

Cell[TextData[{
 "Durch die Festlegung der Markov-Ordnung (hier ",
 StyleBox["p",
  FontSlant->"Italic"],
 " = 6) wird die Dimension des Parametervektors \[Alpha] festgelegt. Der \
Vektor \[Alpha], dessen Komponenten wir hier von Hand vorgeben, beschreibt \
die St\[ADoubleDot]rke der Korrelation im Abstand ",
 StyleBox["k",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.6761564707065907`*^9, 3.676156526383494*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"p", "=", "6"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vecAlpha", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
      "0.5", ",", "0.1", ",", "0.1", ",", "0.1", ",", "0.1", ",", "0.1"}], 
      "}"}]}], "}"}]}], ";"}]], "Input"],

Cell["\<\
Wir w\[ADoubleDot]hlen eine Verteilung, bei der die Wahrscheinlichkeit, eine \
Eins als R\[UDoubleDot]ckgriffweite zu erhalten, 50 % betr\[ADoubleDot]gt. \
Die verbleibenden f\[UDoubleDot]nf Werte 2, . . . , 6 werden mit der gleichen \
Wahrscheinlichkeit 1/10 angenommen. Die Summe der Wahrscheinlichkeiten muss \
aus Normierungsgr\[UDoubleDot]nden Eins ergeben.\
\>", "Text",
 CellChangeTimes->{{3.6761566142430553`*^9, 3.6761566371688967`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", "vecAlpha", "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "2", "3", "4", "5", "6"},
    {"0.5`", "0.1`", "0.1`", "0.1`", "0.1`", "0.1`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.677571935517552*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plus", "@@", 
  RowBox[{"vecAlpha", "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input"],

Cell[BoxData["1.`"], "Output",
 CellChangeTimes->{3.677571935548752*^9}]
}, Open  ]],

Cell["\<\
Auch die Verteilung der unabh\[ADoubleDot]ngig voneinander gezogenen Symbole, \
also des zuf\[ADoubleDot]lligen Sequenzbeitrags, muss spezifiziert werden. \
Hier w\[ADoubleDot]hlen wir eine Gleichverteilung.\
\>", "Text",
 CellChangeTimes->{{3.6761566553251305`*^9, 3.676156696809806*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"distY", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<A\>\"", ",", "\"\<G\>\"", ",", "\"\<C\>\"", ",", "\"\<T\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.25", ",", "0.25", ",", "0.25", ",", "0.25"}], "}"}]}], 
    "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", "distY", "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"A\"\>", "\<\"G\"\>", "\<\"C\"\>", "\<\"T\"\>"},
    {"0.25`", "0.25`", "0.25`", "0.25`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6775719355799522`*^9}]
}, Open  ]],

Cell[TextData[{
 "Das folgende Modul liefert eine ganze Zahl zwischen 1 und der Ordnung ",
 StyleBox["p",
  FontSlant->"Italic"],
 " des Prozesses als Funktionswert. Das Argument ist der Parametervektor \
\[Alpha]. Dabei nutzen wir das Prinzip der Zerlegung der Einheit, das wir \
schon in dem ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs in Kap. 2.2 kennengelernt haben. Dieser Befehl ist damit eine \
Realisierung der Zufallsvariablen ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "n"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " aus Gl. (4.16)."
}], "Text",
 CellChangeTimes->{{3.6761567641515293`*^9, 3.676156822380436*^9}, 
   3.6761569687517033`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"A", "[", "vec_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmp1", ",", "tmp2"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"tmp1", "=", 
       RowBox[{"Random", "[", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmp2", "=", 
       RowBox[{"FoldList", "[", 
        RowBox[{"Plus", ",", "0", ",", 
         RowBox[{"vec", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Position", "[", 
         RowBox[{
          RowBox[{"Sort", "[", 
           RowBox[{"Append", "[", 
            RowBox[{"tmp2", ",", "tmp1"}], "]"}], "]"}], ",", "tmp1"}], "]"}],
         "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}]}], " ", 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "[", "vecAlpha", "]"}]], "Input"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.6775719355955524`*^9}]
}, Open  ]],

Cell[TextData[{
 "In \[ADoubleDot]hnlicher Weise definieren wir eine Funktion, die ein zuf\
\[ADoubleDot]lliges Symbol ausgibt. Hier ist der Funktionswert jedoch ein \
explizites Symbol und keine Zahl, die angibt, auf welches bereits vorliegende \
Symbol zur\[UDoubleDot]ckgegriffen wird. Diese Gr\[ODoubleDot]\[SZ]e stellt \
die Zufallsvariable ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["Y", "n"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " in Gl. (4.20) dar."
}], "Text",
 CellChangeTimes->{{3.6761572381427965`*^9, 3.6761572862724843`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Y", "[", "dist_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmp1", ",", "tmp2", ",", "tmp3"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"tmp1", "=", 
       RowBox[{"Random", "[", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmp2", "=", 
       RowBox[{"FoldList", "[", 
        RowBox[{"Plus", ",", "0", ",", 
         RowBox[{"dist", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"tmp2", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "\[LessEqual]", "tmp1", "<", 
            RowBox[{"tmp2", "[", 
             RowBox[{"[", 
              RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ",", 
           RowBox[{"tmp3", "=", 
            RowBox[{"dist", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "i"}], "]"}], "]"}]}]}], "]"}], ";"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{
           RowBox[{"Length", "[", "tmp2", "]"}], "-", "1"}]}], "}"}]}], "]"}],
       ";", "\[IndentingNewLine]", "tmp3"}]}], "\[IndentingNewLine]", "]"}]}],
   ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Y", "[", "distY", "]"}]], "Input"],

Cell[BoxData["\<\"G\"\>"], "Output",
 CellChangeTimes->{3.677571935642352*^9}]
}, Open  ]],

Cell[TextData[{
 "Um den Prozess zu initialisieren, m\[UDoubleDot]ssen nun genau ",
 StyleBox["p",
  FontSlant->"Italic"],
 " Symbole festgelegt werden. Erst dann kann die Rekursion begonnen werden. \
Diese ",
 StyleBox["p",
  FontSlant->"Italic"],
 " Werte sind ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["X", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " bis ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["X", "p"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". Sie werden zuf\[ADoubleDot]llig nach der Verteilung von ",
 StyleBox["Y",
  FontSlant->"Italic"],
 " gezogen."
}], "Text",
 CellChangeTimes->{{3.6761574452917757`*^9, 3.676157505512886*^9}}],

Cell[BoxData[
 RowBox[{"SeedRandom", "[", "1", "]"}]], "Input",
 CellChangeTimes->{3.670427636734831*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"X", "[", "n", "]"}], "=", 
    RowBox[{"Y", "[", "distY", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "p"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"A\"\>", 
   ",", "\<\"T\"\>", ",", "\<\"C\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.6775719356735525`*^9}]
}, Open  ]],

Cell[TextData[{
 "Die eigentliche Rekursion besteht nun im Aufruf der einzelnen oben \
beschriebenen Funktionen. F\[UDoubleDot]r den Fall, dass eine gezogene \
Zufallszahl kleiner ist als der Parameter \[Rho], wird ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["X", "n"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " durch einen R\[UDoubleDot]ckgriff in der Sequenz bestimmt. Dabei liefert \
die Funktion ",
 StyleBox["A",
  FontSlant->"Italic"],
 " gerade die Anzahl von Schritten, die zur\[UDoubleDot]ckgegangen wird."
}], "Text",
 CellChangeTimes->{{3.6761575561953793`*^9, 3.6761575630849915`*^9}, {
  3.676157597037854*^9, 3.6761576267451086`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Random", "[", "]"}], "<", "\[Rho]"}], ",", 
     RowBox[{
      RowBox[{"X", "[", "n", "]"}], "=", 
      RowBox[{"X", "[", " ", 
       RowBox[{"n", "-", 
        RowBox[{"A", "[", "vecAlpha", "]"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"X", "[", "n", "]"}], "=", 
      RowBox[{"Y", "[", "distY", "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"n", ",", 
     RowBox[{"p", "+", "1"}], ",", "100"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"T\"\>", ",", "\<\"C\"\>", ",", "\<\"T\"\>", ",", "\<\"A\"\>", 
   ",", "\<\"C\"\>", ",", "\<\"A\"\>", ",", "\<\"T\"\>", ",", "\<\"G\"\>", 
   ",", "\<\"G\"\>", ",", "\<\"G\"\>", ",", "\<\"A\"\>", ",", "\<\"T\"\>", 
   ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"A\"\>", 
   ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"C\"\>", 
   ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", 
   ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", 
   ",", "\<\"A\"\>", ",", "\<\"A\"\>", ",", "\<\"A\"\>", ",", "\<\"C\"\>", 
   ",", "\<\"C\"\>", ",", "\<\"C\"\>", ",", "\<\"C\"\>", ",", "\<\"A\"\>", 
   ",", "\<\"A\"\>", ",", "\<\"C\"\>", ",", "\<\"A\"\>", ",", "\<\"A\"\>", 
   ",", "\<\"A\"\>", ",", "\<\"C\"\>", ",", "\<\"C\"\>", ",", "\<\"C\"\>", 
   ",", "\<\"C\"\>", ",", "\<\"C\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", 
   ",", "\<\"C\"\>", ",", "\<\"T\"\>", ",", "\<\"C\"\>", ",", "\<\"C\"\>", 
   ",", "\<\"T\"\>", ",", "\<\"C\"\>", ",", "\<\"C\"\>", ",", "\<\"C\"\>", 
   ",", "\<\"C\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", 
   ",", "\<\"C\"\>", ",", "\<\"A\"\>", ",", "\<\"A\"\>", ",", "\<\"T\"\>", 
   ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"C\"\>", 
   ",", "\<\"C\"\>", ",", "\<\"T\"\>", ",", "\<\"A\"\>", ",", "\<\"C\"\>", 
   ",", "\<\"C\"\>", ",", "\<\"A\"\>", ",", "\<\"A\"\>", ",", "\<\"C\"\>", 
   ",", "\<\"A\"\>", ",", "\<\"C\"\>", ",", "\<\"C\"\>", ",", "\<\"A\"\>", 
   ",", "\<\"C\"\>", ",", "\<\"C\"\>", ",", "\<\"C\"\>", ",", "\<\"C\"\>", 
   ",", "\<\"C\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", 
   ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", ",", "\<\"T\"\>", 
   ",", "\<\"A\"\>", ",", "\<\"G\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.6775719356891527`*^9}]
}, Open  ]],

Cell["\<\
Mithilfe z.B. der Transinformation kann nun die Markov-Eigenschaft einer \
solchen Sequenz sichtbar gemacht werden, so wie wir es im Verlauf des \
Kapitels diskutiert haben.\
\>", "Text",
 CellChangeTimes->{{3.6761576702821903`*^9, 3.6761577184006796`*^9}}]
}, Open  ]]
},
WindowSize->{507, 900},
WindowMargins->{{608, Automatic}, {Automatic, 191}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 870, 36, 182, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1452, 60, 354, 12, 66, "Subtitle"],
Cell[1809, 74, 680, 15, 125, "Text"],
Cell[2492, 91, 74, 2, 31, "Input"],
Cell[2569, 95, 434, 11, 87, "Text"],
Cell[3006, 108, 67, 2, 31, "Input"],
Cell[3076, 112, 341, 11, 52, "Input"],
Cell[3420, 125, 456, 7, 125, "Text"],
Cell[CellGroupData[{
Cell[3901, 136, 69, 1, 31, "Input"],
Cell[3973, 139, 634, 17, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4644, 161, 112, 3, 31, "Input"],
Cell[4759, 166, 72, 1, 31, "Output"]
}, Open  ]],
Cell[4846, 170, 299, 5, 68, "Text"],
Cell[5148, 177, 329, 11, 52, "Input"],
Cell[CellGroupData[{
Cell[5502, 192, 66, 1, 31, "Input"],
Cell[5571, 195, 646, 17, 56, "Output"]
}, Open  ]],
Cell[6232, 215, 690, 18, 144, "Text"],
Cell[6925, 235, 933, 27, 132, "Input"],
Cell[CellGroupData[{
Cell[7883, 266, 61, 1, 31, "Input"],
Cell[7947, 269, 72, 1, 31, "Output"]
}, Open  ]],
Cell[8034, 273, 559, 12, 106, "Text"],
Cell[8596, 287, 1401, 39, 192, "Input"],
Cell[CellGroupData[{
Cell[10022, 330, 58, 1, 31, "Input"],
Cell[10083, 333, 78, 1, 31, "Output"]
}, Open  ]],
Cell[10176, 337, 682, 23, 90, "Text"],
Cell[10861, 362, 169, 4, 47, "Input"],
Cell[CellGroupData[{
Cell[11055, 370, 228, 7, 31, "Input"],
Cell[11286, 379, 209, 4, 31, "Output"]
}, Open  ]],
Cell[11510, 386, 663, 15, 125, "Text"],
Cell[CellGroupData[{
Cell[12198, 405, 600, 17, 92, "Input"],
Cell[12801, 424, 1881, 26, 165, "Output"]
}, Open  ]],
Cell[14697, 453, 267, 5, 68, "Text"]
}, Open  ]]
}
]
*)

